
:autogenerated:

weylchamber.coordinates module
==============================

.. currentmodule:: weylchamber.coordinates

.. automodule:: weylchamber.coordinates
    :members: And, DEFAULT_WEYL_PRECISSION, Or, c1c2c3, canonical_gate, from_magic, greater, greater_eq, less, less_eq, point_in_region, point_in_weyl_chamber, random_gate, random_weyl_point, to_magic, weyl_region
    :undoc-members:
    :show-inheritance:
    :member-order: bysource

    Summary
    -------

    Functions:

    .. autosummary::
        :nosignatures:

        c1c2c3
        canonical_gate
        from_magic
        point_in_region
        point_in_weyl_chamber
        random_gate
        random_weyl_point
        to_magic
        weyl_region





    ``__all__``: :func:`c1c2c3 <weylchamber.coordinates.c1c2c3>`, :func:`canonical_gate <weylchamber.coordinates.canonical_gate>`, :func:`from_magic <weylchamber.coordinates.from_magic>`, :func:`point_in_region <weylchamber.coordinates.point_in_region>`, :func:`point_in_weyl_chamber <weylchamber.coordinates.point_in_weyl_chamber>`, :func:`random_gate <weylchamber.coordinates.random_gate>`, :func:`random_weyl_point <weylchamber.coordinates.random_weyl_point>`, :func:`to_magic <weylchamber.coordinates.to_magic>`, :func:`weyl_region <weylchamber.coordinates.weyl_region>`



    Reference
    ---------